@@ -1,10 +1,10 @@
 package Perinci::To::Text::I18N::en;
-use parent qw(Perinci::To::Text::I18N Perinci::To::DocBase::I18N::en);
+use parent qw(Perinci::To::Text::I18N Perinci::To::PackageBase::I18N::en);
 
 use Locale::Maketext::Lexicon::Gettext;
 our %Lexicon = %{ Locale::Maketext::Lexicon::Gettext->parse(<DATA>) };
 
-our $VERSION = '0.07'; # VERSION
+our $VERSION = '0.08'; # VERSION
 
 #use Data::Dump; dd \%Lexicon;
 
@@ -20,7 +20,7 @@ Perinci::To::Text::I18N::en - English translation for Perinci::To::Text
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 AUTHOR
 
